# Supported Languages

**Mehen** supports these programming languages:

- [x] **Go** (.go) - via tree-sitter-go v0.23.4
- [x] **Python** (.py) - via tree-sitter-python v0.23.6
- [x] **Rust** (.rs) - via tree-sitter-rust v0.23.2
- [x] **TypeScript** (.ts, .jsw, .jsmw) - via tree-sitter-typescript v0.23.2
- [x] **TSX** (.tsx) - via tree-sitter-typescript v0.23.2
